<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 *
 * @package   theme_mb2nl
 * @copyright 2017 - 2022 Mariusz Boloz (mb2moodle.com)
 * @license   Commercial https://themeforest.net/licenses
 *
 */

defined('MOODLE_INTERNAL') || die();

$mb2section = theme_mb2nl_mb2fields_filed('mb2section') && theme_mb2nl_theme_setting($PAGE, 'csection');
$skills = theme_mb2nl_mb2fields_filed('mb2skills');
$requirements = theme_mb2nl_mb2fields_filed('mb2requirements');
$reviews = theme_mb2nl_is_review_plugin();
$generalsection = theme_mb2nl_course_general_section();
$generalc = $generalsection['summary'] ? $generalsection['summary'] : get_string('nothingtodisplay');
$reviewlist = '';
$reviewsummary = '';
$startslink = '';
$canrate = '';
$ratealready = '';
$urlctab = optional_param('ctab', '', PARAM_ALPHANUMEXT );


if ( $reviews )
{
	if ( ! class_exists( 'Mb2reviewsHelper' ) )
	{
		require_once( $CFG->dirroot . '/local/mb2reviews/classes/helper.php' );
	}

	$rHlpr = new Mb2reviewsHelper;

	$canrate = $rHlpr->can_rate( $COURSE->id );
	$ratealready = $rHlpr->rate_already( $COURSE->id );
	$reviewlist = $rHlpr->review_list();
	$reviewsummary = $rHlpr->review_summary();
	$courserating = $rHlpr->course_rating($COURSE->id);
	$startslink = method_exists( $rHlpr, 'rating_stars_link' ) ? $rHlpr->rating_stars_link() : '';
}

?>
<?php if ( $vars['layout'] != 3 ) : ?>
    <?php echo theme_mb2nl_tabcontent_topics(); ?>
<?php elseif( $vars['layout'] == 3 && ( $urlctab === 'general' || $urlctab === '' ) ) : ?>
    <div class="course-nav-section csection_general active">
        <div id="course-mb2section" class="details-section mb2section">
            <h2 class="section-heading h3"><?php echo $generalsection['name']; ?></h2>
            <div class="details-content">
                <div class="content-inner"><?php echo $generalc; ?></div>
            </div>
        </div>
    </div>
<?php endif; ?>
<?php if ( $mb2section && $urlctab === 'csection' ) : ?>
    <div class="course-nav-section csection_csection">
        <div id="course-mb2section" class="details-section mb2section">
            <h2 class="section-heading h3"><?php echo theme_mb2nl_mb2sectionfiledname(); ?></h2>
            <div class="details-content">
                <div class="content-inner"><?php echo theme_mb2nl_mb2fields_filed('mb2section'); ?></div>
            </div>
        </div>
    </div>
<?php endif; ?>
<?php if ( ($reviewsummary || $reviewlist || $canrate || $ratealready) && $urlctab === 'reviews' ) : ?>
    <div class="course-nav-section csection_reviews">
        <div id="course-ratings" class="details-section reviews-starslink">
            <?php echo $startslink; ?>
        </div>
        <?php if ( $reviewsummary ) : ?>
            <div id="course-ratings" class="details-section reviews-summary">
                <h2 class="section-heading h3"><?php echo get_string( 'courserating', 'local_mb2reviews' ); ?></h2>
                <?php echo $reviewsummary; ?>
            </div>
        <?php endif; ?>
        <?php if ( $reviewlist ) : ?>
            <div class="details-section reviews">
                <h2 class="section-heading h3"><?php echo get_string( 'reviews', 'local_mb2reviews' ); ?></h2>
                <?php echo $reviewlist; ?>
            </div>
        <?php endif; ?>
    </div>
<?php endif; ?>
<?php if ( $urlctab === 'courseinfo' ) : ?>
    <div class="course-nav-section csection_courseinfo">
        <div id="course-mb2section" class="details-section mb2section">
            <div class="section-content">
                <div class="content-inner">
                    <div class="course-summary course-section-part">
                        <h2 class="section-heading h3"><?php echo get_string('coursesummary'); ?></h2>
                        <div><div><?php echo theme_mb2nl_get_mb2course_description(); ?></div></div>
                        <?php echo theme_mb2nl_moreless(); ?>
                    </div>
                    <?php if ( $skills ) : ?>
                        <div class="course-skills course-section-part">
                            <h2 class="section-heading h3"><?php echo get_string( 'headingwhatlearn', 'theme_mb2nl' ); ?></h2>		
                            <div class="content-inner"><?php echo theme_mb2nl_sr_list($skills); ?></div>
                        </div>
                    <?php endif; ?>
                    <?php if ( $requirements ) : ?>
                        <div class="course-requirements course-section-part">
                            <h2 class="section-heading h3"><?php echo get_string( 'headingrequirements', 'theme_mb2nl' ); ?></h2>
                            <div class="content-inner"><?php echo theme_mb2nl_sr_list( $requirements, false, 999, 2 ); ?></div>
                        </div>
                    <?php endif; ?>
                    <div class="course-section-part">
                        <h2 class="section-heading h3"><?php echo get_string( 'headinginstructors', 'theme_mb2nl' ); ?></h2>
                        <?php echo theme_mb2nl_course_teachers_list($reviews, true); ?>
                    </div>
                    <?php echo theme_mb2nl_course_info_table(); ?>
                </div>
            </div>
        </div>
    </div>
<?php endif; ?>
