<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 *
 * @package   theme_mb2nl
 * @copyright 2017 - 2022 Mariusz Boloz (mb2moodle.com)
 * @license   Commercial https://themeforest.net/licenses
 *
 */

defined('MOODLE_INTERNAL') || die();

$loginicon = ! isloggedin() || isguestuser() ? 'ri-lock-fill' : 'ri-user-3-fill';
$logintext = ! isloggedin() || isguestuser() ? get_string('login') : $USER->firstname;
$btncls = theme_mb2nl_bsfcls(2,'column','center','center');
$headercontent = theme_mb2nl_theme_setting($PAGE, 'headercontent') && theme_mb2nl_static_content( theme_mb2nl_theme_setting($PAGE, 'headercontent'), false );

?>
<div class="mnavtop menu-extracontent">
	<div class="menu-extracontent-controls<?php echo theme_mb2nl_bsfcls(1,'row','center','center'); ?>">
		<?php if ( theme_mb2nl_site_menu() && ! theme_mb2nl_is_tgsdb() ) : ?>
			<button class="themereset p-0 menu-extra-controls-btn menu-extra-controls-quicklinks<?php echo $btncls; ?>" aria-label="<?php echo get_string('quicklinks', 'theme_mb2nl'); ?>" aria-controls="menu-quicklinkscontainer" aria-expanded="false"><i class="ri-apps-2-fill"></i><span class="d-block mt-1 label<?php echo theme_mb2nl_tcls('xxsmall'); ?>"><?php echo get_string('quicklinks', 'theme_mb2nl'); ?></span></button>
		<?php endif; ?>
		<button class="themereset p-0 menu-extra-controls-btn menu-extra-controls-search<?php echo $btncls; ?>" aria-label="<?php echo get_string('togglesearch', 'theme_mb2nl'); ?>" aria-controls="menu-searchcontainer" aria-expanded="false"><i class="ri-search-line"></i><span class="d-block mt-1 label<?php echo theme_mb2nl_tcls('xxsmall'); ?>"><?php echo get_string('search'); ?></span></button>
		<button class="themereset p-0 menu-extra-controls-btn menu-extra-controls-login<?php echo $btncls; ?>" aria-label="<?php echo get_string('togglelogin', 'theme_mb2nl'); ?>" aria-controls="menu-logincontainer" aria-expanded="false"><i class="<?php echo $loginicon ; ?>"></i><span class="d-block mt-1 label<?php echo theme_mb2nl_tcls('xxsmall'); ?>"><?php echo $logintext; ?></span></button>
		<?php if ( $headercontent ) : ?>
			<button class="themereset p-0 menu-extra-controls-btn menu-extra-controls-content<?php echo $btncls; ?>" aria-label="<?php echo get_string('toggleheadercontent', 'theme_mb2nl'); ?>" aria-controls="menu-staticontentcontainer" aria-expanded="false"><i class="ri-information-line"></i><span class="d-block mt-1 label<?php echo theme_mb2nl_tcls('xxsmall'); ?>"><?php echo get_string('info'); ?></span></button>
		<?php endif; ?>
	</div>
	<?php if ( theme_mb2nl_site_menu() && ! theme_mb2nl_is_tgsdb() ) : ?>
		<div id="menu-quicklinkscontainer" class="menu-extracontent-content">
			<?php echo theme_mb2nl_site_menu(true); ?>
		</div>
	<?php endif; ?>
	<?php echo theme_mb2nl_search_form( true ); ?>
	<?php echo theme_mb2nl_login_form(false, true); ?>
	<?php if ( $headercontent ) : ?>
		<div id="menu-staticontentcontainer" class="menu-extracontent-content">
			<?php echo theme_mb2nl_static_content( theme_mb2nl_theme_setting($PAGE, 'headercontent'), true, true, array( 'listcls' => 'mobile-header-list' ) ); ?>
		</div>
	<?php endif; ?>
</div>