<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 *
 * @package   theme_mb2nl
 * @copyright 2017 - 2022 Mariusz Boloz (mb2moodle.com)
 * @license   Commercial https://themeforest.net/licenses
 *
 */


defined('MOODLE_INTERNAL') || die();

/*
 *
 * Method to check if is toggle sidebar
 *
 */
function theme_mb2nl_is_tgsdb()
{

	global $PAGE, $CFG;

	if ( $PAGE->pagelayout === 'mb2builder' || $PAGE->pagelayout === 'mb2builder_form' || theme_mb2nl_is_login(true) )
	{
		return false;
	}

	if ( ( theme_mb2nl_tgsdb_setting() || theme_mb2nl_full_screen_module() ) && ( theme_mb2nl_is_toc() || theme_mb2nl_isblock($PAGE, 'side-pre') || theme_mb2nl_rating_block() || theme_mb2nl_site_menu() ) )
	{
		return true;
	}

	return false;

}




/*
 *
 * Method to check if is toggle sidebar settin enabled
 *
 */
function theme_mb2nl_tgsdb_setting()
{

	global $PAGE;

	$builder_tgsdb = theme_mb2nl_builder_tgsdb();
	$tgsdbfield = theme_mb2nl_mb2fields_filed('mb2tgsdb');
	$tgsdb = theme_mb2nl_theme_setting($PAGE, 'tgsdb');

	if ( $builder_tgsdb != 0 )
	{
		$tgsdb = $builder_tgsdb == -1 ? 0 : 1;
	}
	elseif ( ! is_null( $tgsdbfield ) && $tgsdbfield !== '' )
	{
		$tgsdb = $tgsdbfield;
	}

	return $tgsdb;

}





/*
 *
 * Method to get toggle sidebar
 *
 */
function theme_mb2nl_tgsdb()
{
	global $CFG, $OUTPUT, $PAGE;

	$output = '';

	if ( ! theme_mb2nl_is_tgsdb() )
	{
		return;
	}

	// Table of contents
	$clayout = theme_mb2nl_course_layout();

	// Quick links
	$qlinks = theme_mb2nl_site_menu(true);
	
	// Rating block
	$ratingblock = theme_mb2nl_rating_block('toggle-block');
	$ratingblock = $ratingblock && ! in_array($clayout, theme_mb2nl_notoc()) ? $ratingblock : false;

	// Blocks
	$blocks = theme_mb2nl_isblock($PAGE, 'side-pre') || $ratingblock;

	// Course home section
	$chome = theme_mb2nl_is_chome();

	// Active class
	$active = theme_mb2nl_tgsdb_active();
	$active_qlinks = $active === 'qlinks' ? ' active' : '';
	$active_toc = $active === 'toc' ? ' active' : '';
	$active_blocks = $active === 'blocks' ? ' active' : '';
	$active_chome = $active === 'chome' ? ' active' : '';
	$active_settings = $active === 'settings' ? ' active' : '';

	$output .= '<div class="toggle-sidebar pagelayout-a' . theme_mb2nl_bsfcls(1,'column') . '">';
	$output .= '<div class="header-gap"></div>';
	$output .= '<div class="sidebar-content">';
	$output .= theme_mb2nl_tgsdb_button();
	$output .= theme_mb2nl_tgsdb_nav();
	$output .= '<div class="sidebar-content-inner">';
	
	if ( $chome )
	{
		$output .= '<div id="tgsdb_chome" class="tgsdb-section tgsdb-chome' . $active_chome . '">';
		$output .= theme_mb2nl_tgsdb_chome();
		$output .= '</div>'; // tgsdb-chome
	}

	if ( theme_mb2nl_is_toc() )
	{
		$output .= '<div id="tgsdb_toc" class="tgsdb-section tgsdb-toc' . $active_toc . '">';
		$output .= theme_mb2nl_module_sections();
		$output .= '</div>'; // tgsdb-toc
	}

	if ( $blocks )
	{
		$output .= '<div id="tgsdb_blocks" class="tgsdb-section tgsdb-blocks' . $active_blocks . '">';
		$output .= $ratingblock;
		$output .= $OUTPUT->blocks('side-pre', 'toggle-block');
		$output .= '</div>'; // tgsdb-blocks
	}

	if ( $qlinks )
	{
		$output .= '<div id="tgsdb_qlinks" class="tgsdb-section tgsdb-qlinks' . $active_qlinks . '">';
		$output .= $qlinks;
		$output .= '</div>'; // tgsdb-qlinks
	}

	if ( is_siteadmin() )
	{
		$output .= '<div id="tgsdb_settings" class="tgsdb-section tgsdb-settings' . $active_settings . '">';
		$output .= theme_mb2nl_theme_links(false, false, 'quicklinks-list');
		$output .= '</div>'; // tgsdb-qlinks
	}
	
	//$output .= $coursesfilter;
	
	$output .= '</div>'; // sidebar-content-inner
	$output .= '</div>'; // sidebar-content
	$output .= '</div>'; // toggle-sidebar

	return $output;

}




/*
 *
 * Method to get toggle sidebar navigation
 *
 */
function theme_mb2nl_tgsdb_button()
{
	global $PAGE;
	
	$output = '';

	$tgsdbdefault = theme_mb2nl_theme_setting($PAGE,'sidebarbtn') == 2 ? 0 : 1;
	$expanded = theme_mb2nl_user_preference('mb2_tgsdb', $tgsdbdefault) ? 'true' : 'false';

	$output .= '<button type="button" class="tgsdb_btn p-0' . theme_mb2nl_bsfcls(2,'','center','center') . '" aria-label="' . get_string('tgsdb','theme_mb2nl') . '" aria-expanded="' . $expanded . '">';
	$output .= '<i class="ri-arrow-right-double-line"></i>';
	$output .= '</button>';

	return $output;
}



/*
 *
 * Method to get toggle sidebar navigation
 *
 */
function theme_mb2nl_tgsdb_navitems()
{
	global $PAGE;

	$items = array(
		array(
			'id' => 'chome',
			'label' => get_string('courseinfo'),
			'icon' => '<i class="ri-home-fill"></i>',
			'show' => theme_mb2nl_is_chome()
		),
		array(
			'id' => 'toc',
			'label' => get_string('sections'),
			'icon' => '<i class="ri-align-left"></i>',
			'show' => theme_mb2nl_is_toc()
		),
		array(
			'id' => 'qlinks',
			'label' => get_string('quicklinks', 'theme_mb2nl'),
			'icon' => '<i class="ri-apps-2-fill"></i>',
			'show' => theme_mb2nl_site_menu()
		),		
		array(
			'id' => 'blocks',
			'label' => get_string('blocks'),
			'icon' => '<i class="ri-square-fill"></i>',
			'show' => theme_mb2nl_isblock($PAGE, 'side-pre') || theme_mb2nl_rating_block()
		),
		array(
			'id' => 'settings',
			'label' => get_string('settings'),
			'icon' => '<i class="ri-list-settings-fill"></i>',
			'show' => is_siteadmin()
		)		
	);

	return $items;

}



/*
 *
 * Method to get toggle sidebar navigation
 *
 */
function theme_mb2nl_tgsdb_nav()
{
	
	global $PAGE;
	
	$output = '';
	$active = theme_mb2nl_tgsdb_active();
	$items = theme_mb2nl_tgsdb_navitems();

	$output .= '<div class="toggle-sidebar-nav pl-2' . theme_mb2nl_bsfcls(1,'row','','center') . '">';	

	foreach( $items as $item )
	{
		if ( ! $item['show'] )
		{
			continue;
		}

		$sctivecls = $active === $item['id'] ? ' active' : '';
		$expanded = $active === $item['id'] ? 'true' : 'false';

		$output .= '<button type="button" class="themereset tgsdb-btn p-0 pr-2' . theme_mb2nl_bsfcls(2,'column','between','center') . $sctivecls . '" data-id="' . $item['id'] . '" aria-controls="tgsdb_' . $item['id'] . '" aria-label="' . $item['label'] . '" aria-expanded="' . $expanded . '">';
		$output .= $item['icon'];
		$output .= '<span class="label' . theme_mb2nl_tcls('xxsmall') . '">' . $item['label'] . '</span>';
		$output .= '</button>';

	}
	
	$output .= '</div>'; // toggle-sidebar-nav

	return $output;
}



/*
 *
 * Method to get toggle sidebar active item
 *
 */
function theme_mb2nl_tgsdb_active()
{
	global $CFG, $PAGE;

	if ( $CFG->version < 2023100900 ) // Up to Moodle 4.3
	{
		user_preference_allow_ajax_update('mb2_tgsdbactv', PARAM_ALPHA);
	}

	$pref = theme_mb2nl_user_preference('mb2_tgsdbactv', 'qlinks');
	$blocks = theme_mb2nl_isblock($PAGE, 'side-pre') || theme_mb2nl_rating_block();
	$chome = theme_mb2nl_is_chome();
	
	if ( $pref === 'chome' && $chome && ! theme_mb2nl_is_module_context() )
	{
		return 'chome';
	}
	elseif ( (! theme_mb2nl_site_menu() && ! theme_mb2nl_is_toc() && $blocks) || ($pref === 'blocks' && $blocks) || $PAGE->user_is_editing() || (! theme_mb2nl_site_menu() && theme_mb2nl_has_builderpage() && $blocks) )
	{
		return 'blocks';
	}
	elseif ( theme_mb2nl_is_toc() )
	{
		return 'toc';
	}	
	elseif ( $pref === 'settings' &&  preg_match( '@admin-@', $PAGE->pagetype ) )
	{
		return 'settings';
	}

	return 'qlinks';
}





/*
 *
 * Method to get rating block
 *
 */
function theme_mb2nl_rating_block($style = '')
{
	global $CFG, $PAGE;

	$ratingblock = false;
	$style = $style ? $style : theme_mb2nl_theme_setting($PAGE, 'blockstyle2');

	// In some course layouts reating blocks is not displayed
	if ( in_array(theme_mb2nl_course_layout(), theme_mb2nl_noratingblock()) )
	{
		return false;
	}

	if ( theme_mb2nl_is_review_plugin() )
	{
		if ( ! class_exists( 'Mb2reviewsHelper' ) )
		{
			require_once( $CFG->dirroot . '/local/mb2reviews/classes/helper.php' );
		}

		$ratingblock = Mb2reviewsHelper::rating_block($style);
	}

	return $ratingblock;

}





/*
 *
 * Method to get course sidebar home section
 *
 */
function theme_mb2nl_tgsdb_chome()
{
	global $COURSE, $SITE;

	if ( ! theme_mb2nl_is_course() )
	{
		return;
	}

	$output = '';
	$slogan = theme_mb2nl_course_intro($COURSE);
	$svg = theme_mb2nl_svg();
	$catname = theme_mb2nl_get_category_record($COURSE->category, 'id, name')->name;
	$catlink = new moodle_url('/course/', array('categoryid'=>$COURSE->category));
	$actres = theme_mb2nl_get_course_activities($COURSE, true);

	$output .= '<div class="course-sidebar-home">';
	$output .= theme_mb2nl_full_screen_module_backlink(false, false);
	$output .= '<div class="h5">' . format_text($COURSE->fullname, FORMAT_HTML) . '</div>';
	$output .= '<img class="course-image lazy" src="' . theme_mb2nl_lazy_plc() . '" data-src="' . theme_mb2nl_course_image_url($COURSE->id, true) . '" alt="' . format_text($COURSE->fullname, FORMAT_HTML) . '">';
	$output .= $slogan ? '<div class="course-slogan">' . $slogan . '</div>' : '';
	$output .= '<div class="course-details">';
	$output .= '<div class="details-item' . theme_mb2nl_bsfcls(1,'row','','center') . '">';
	$output .= '<div class="item-icon' . theme_mb2nl_bsfcls(2,'','center','center') . '">' . $svg['folder'] . '</div>';
	$output .= '<div class="item-content' . theme_mb2nl_bsfcls(1,'column') . '">';
	$output .= '<span class="item-label">' . get_string('category') . ':</span>';
	$output .= '<span class="item-value"><a href="' . $catlink . '">' . $catname . '</a></span>';
	$output .= '</div>'; // item-content
	$output .= '</div>'; // details-item
	$output .= '<div class="details-item' . theme_mb2nl_bsfcls(1,'row','','center') . '">';
	$output .= '<div class="item-icon' . theme_mb2nl_bsfcls(2,'','center','center') . '">' . $svg['boxes-packing'] . '</div>';
	$output .= '<div class="item-content' . theme_mb2nl_bsfcls(1,'column') . '">';
	$output .= '<span class="item-label">' . get_string('activitiesresources', 'theme_mb2nl') . ':</span>';
	$output .= '<span class="item-value">' . $actres->activities . '/' . $actres->resources . '</span>';
	$output .= '</div>'; // item-content
	$output .= '</div>'; // details-item
	$output .= '</div>'; // course-details
	$output .= theme_mb2nl_course_fields( $COURSE->id, false );
	$output .= '</div>'; // course-sidebar-home

	return $output;

}